@@ -1,7 +1,7 @@
 from mpet.props_am import step_down
 
 
-def LiC6_ss2(self, y, ybar, muR_ref, ISfuncs=None):
+def LiC6_ss2(self, y, ybar, muR_ref):
     """ Bernardi and Go 2011 """
     p1, p2, p3, p4 = (0.085, 0.120, 0.210, 3.5)
     sfac = 0.3
