@@ -1,7 +1,7 @@
 import numpy as np
 
 
-def LiMn2O4_ss(self, y, ybar, muR_ref, ISfuncs=None):
+def LiMn2O4_ss(self, y, ybar, muR_ref):
     """ Doyle, Newman, 1996 """
     # OCV in V vs Li/Li+
     OCV = (4.19829 + 0.0565661*np.tanh(-14.5546*y + 8.60942)
