@@ -1,7 +1,7 @@
 import numpy as np
 
 
-def LiMn2O4_ss2(self, y, ybar, muR_ref, ISfuncs=None):
+def LiMn2O4_ss2(self, y, ybar, muR_ref):
     """ Fuller, Doyle, Newman, 1994 """
     # OCV in V vs Li/Li+
     OCV = (4.06279 + 0.0677504*np.tanh(-21.8502*y + 12.8268)
