@@ -1,7 +1,7 @@
 import numpy as np
 
 
-def NCA_ss2(self, y, ybar, muR_ref, ISfuncs=None):
+def NCA_ss2(self, y, ybar, muR_ref):
     """
     Li_q Ni(0.8)Co(0.15)Al(0.05)O2
     as a function of y. Here, y actually represents a practical
